var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ChangeDetectionStrategy, ChangeDetectorRef, Renderer } from '@angular/core';
import { Input, Output, EventEmitter, ViewChild, ContentChildren, ContentChild, QueryList } from '@angular/core';
import { DatePickerField, DatePickerFieldStyler } from "./DatePickerField";
import { InfiniteScroller } from "../InfiniteScroller/InfiniteScroller";
import { DateUtils, MobileDetection } from "../../utilities/utilities";
export let DatePicker = class DatePicker {
    constructor(changeDetector, renderer) {
        this._minDate = new Date(1900, 0, 1);
        this._maxDate = new Date(2200, 0, 1);
        this.valueChange = new EventEmitter();
        this.calendarDisplayed = false;
        this.calendarX = "5%";
        this.calendarY = "5%";
        this.calendarHeight = MobileDetection.isAny() || window.innerWidth <= 480 || window.outerWidth <= 480 ? "auto" : "300px";
        this.calendarMonths = [];
        this._preGenMonths = 2;
        this.initialScroll = true;
        this.changeDetector = changeDetector;
        this.renderer = renderer;
        this.generateMonths();
    }
    set minDate(value) {
        this._minDate = DateUtils.handleDateInput(value);
    }
    get minDate() { return this._minDate; }
    ;
    set maxDate(value) {
        this._maxDate = DateUtils.handleDateInput(value);
    }
    get maxDate() { return this._maxDate; }
    set value(value) {
        this._selectedDate = DateUtils.handleDateInput(value);
    }
    get inputDate() {
        return this.dateField != null ? this.dateField.value : "";
    }
    get selectedDate() { return this._selectedDate; }
    ;
    set selectedDate(value) {
        this._selectedDate = value;
        if (this.dateField != null && this.dateField.date.getTime() != value.getTime())
            this.dateField.date = value;
        this.valueChange.next(this.selectedDate);
        this.hideCalendar();
    }
    ngOnInit() {
        this.scrollerReset();
    }
    ngAfterContentInit() {
        if (this.dateField == undefined)
            throw "Fuel-UI Error: DatePicker missing date field";
        var parsedDate = DateUtils.handleDateInput(this.dateField.value);
        if (this.dateField.value.length > 0 && DateUtils.isValidDate(parsedDate))
            this.selectedDate = parsedDate;
        this.dateField.select
            .subscribe((event) => {
            this.showCalendar(event);
        });
        /* removed due to binding issues in FF
        this.dateField.dateChange
            .subscribe((date: Date) => {
                if(date.getTime() != this.selectedDate.getTime())
                    this.selectedDate = date;
            });*/
        this.dateFieldIcons.map((i) => {
            i.selectEvent.subscribe((event) => {
                this.showCalendar(event);
            });
        });
        this.generateMonths();
    }
    generateMonths() {
        var currentDate = this.selectedDate != null ? this.selectedDate : new Date();
        this.calendarMonths = [
            new Date(currentDate.getFullYear(), currentDate.getMonth() - 1),
            new Date(currentDate.getFullYear(), currentDate.getMonth())
        ];
        for (let i = 0; i < this._preGenMonths; i++) {
            let earliestDate = this.calendarMonths[0];
            let latestDate = this.calendarMonths[this.calendarMonths.length - 1];
            if (this.canPrevMonth)
                this.calendarMonths.unshift(new Date(earliestDate.getFullYear(), earliestDate.getMonth() - 1));
            if (this.canNextMonth)
                this.calendarMonths.push(new Date(latestDate.getFullYear(), latestDate.getMonth() + 1));
        }
    }
    scrollerReset() {
        setTimeout(() => {
            var currentDate = this.selectedDate != null ? this.selectedDate : new Date();
            if (this.calendarScroller == null)
                return;
            let scrollToMonth = this.calendarMonths.findIndex((m) => {
                return m.getFullYear() == currentDate.getFullYear()
                    && m.getMonth() == currentDate.getMonth();
            });
            if (this.initialScroll) {
                this.initialScroll = false;
                this.calendarScroller.container.scrollTop =
                    this.calendarScroller.itemQuery.toArray()[scrollToMonth]
                        .element.offsetTop - 20;
            }
            this.calendarScroller.scrollToIndex(scrollToMonth);
        }, 1);
    }
    toggleCalendar(event) {
        if (!this.calendarDisplayed)
            this.showCalendar(event);
        else
            this.hideCalendar();
    }
    showCalendar(event) {
        if (event != null && !MobileDetection.isAny()) {
            var clickedTarget = event.target ? event.target.parentElement : event.srcElement.parentElement;
            if (clickedTarget.classList.contains("input-group-addon"))
                clickedTarget = clickedTarget.parentElement;
            this.calendarX = clickedTarget.offsetLeft + "px";
            if (screen.height - clickedTarget.getBoundingClientRect().bottom <= 500) {
                this.calendarY = (clickedTarget.offsetTop - 300) + "px";
            }
            else {
                this.calendarY = clickedTarget.offsetTop + "px";
            }
        }
        else if (MobileDetection.isAny()) {
            this.calendarX = "5%";
            this.calendarY = "5%";
        }
        this.scrollerReset();
        this.changeDetector.markForCheck();
        this.calendarDisplayed = true;
    }
    hideCalendar() {
        this.calendarDisplayed = false;
        this.initialScroll = true;
        this.changeDetector.markForCheck();
    }
    get canPrevMonth() {
        var currentDate = this.calendarMonths[0];
        var prevDate = new Date(currentDate.getFullYear(), currentDate.getMonth() - 1);
        var compareDate = new Date(this._minDate.getFullYear(), this._minDate.getMonth());
        return prevDate >= compareDate;
    }
    get canNextMonth() {
        var currentDate = this.calendarMonths[this.calendarMonths.length - 1];
        var nextDate = new Date(currentDate.getFullYear(), currentDate.getMonth() + 1);
        var compareDate = new Date(this._maxDate.getFullYear(), this._maxDate.getMonth());
        return nextDate <= compareDate;
    }
    disablePrev() {
        return this.calendarScroller ? this.calendarScroller.isTop() : false;
    }
    disableNext() {
        return this.calendarScroller ? this.calendarScroller.isBottom() : false;
    }
    scrollPrevMonth() {
        if (this.calendarScroller.topIndex == 0)
            this.addPrevMonth();
        setTimeout(() => {
            this.calendarScroller.scrollToIndex(this.calendarScroller.topIndex - 1);
        }, 10);
    }
    scrollNextMonth() {
        setTimeout(() => {
            this.calendarScroller.scrollToIndex(this.calendarScroller.topIndex + 1);
        }, 10);
    }
    addNextMonth() {
        if (!this.canNextMonth)
            return;
        var lastMonth = this.calendarMonths[this.calendarMonths.length - 1];
        var nextMonth = new Date(lastMonth.getFullYear(), lastMonth.getMonth() + 1);
        this.calendarMonths.push(nextMonth);
        this.changeDetector.markForCheck();
    }
    addPrevMonth() {
        if (!this.canPrevMonth)
            return;
        var firstMonth = this.calendarMonths[0];
        var prevMonth = new Date(firstMonth.getFullYear(), firstMonth.getMonth() - 1);
        this.calendarMonths.unshift(prevMonth);
        this.changeDetector.markForCheck();
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DatePicker.prototype, "minDate", null);
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DatePicker.prototype, "maxDate", null);
__decorate([
    Input(), 
    __metadata('design:type', Function)
], DatePicker.prototype, "dateFilter", void 0);
__decorate([
    Output(), 
    __metadata('design:type', Object)
], DatePicker.prototype, "valueChange", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DatePicker.prototype, "value", null);
__decorate([
    ViewChild(InfiniteScroller), 
    __metadata('design:type', InfiniteScroller)
], DatePicker.prototype, "calendarScroller", void 0);
__decorate([
    ContentChild(DatePickerField), 
    __metadata('design:type', DatePickerField)
], DatePicker.prototype, "dateField", void 0);
__decorate([
    ContentChildren(DatePickerFieldStyler), 
    __metadata('design:type', QueryList)
], DatePicker.prototype, "dateFieldIcons", void 0);
DatePicker = __decorate([
    Component({
        selector: "date-picker",
        styles: ["\n      .date-picker-overlay {\n        background-color: transparent;\n        display: block;\n        position: fixed;\n        top: 0;\n        right: 0;\n        bottom: 0;\n        left: 0;\n        z-index: 900; }\n        @media (max-width: 480px), screen and (max-device-width: 480px) {\n          .date-picker-overlay {\n            background-color: #55595c;\n            opacity: .75; } }\n\n      .date-picker-content {\n        position: relative;\n        top: 0;\n        left: 0; }\n\n      .fuel-ui-datepicker-input-group input:read-only, .fuel-ui-datepicker-input-group .form-control[readonly] {\n        background-color: #fff !important; }\n\n      .fuel-ui-datepicker-input-group .input-group-addon {\n        background-color: #fff !important; }\n\n      .date-picker-component {\n        border: 1px solid #eceeef;\n        z-index: 1000;\n        background-color: #fff;\n        font-size: .75rem;\n        position: absolute;\n        width: 350px;\n        height: auto;\n        top: 0;\n        left: 0;\n        overflow: hidden;\n        border-radius: 0.3rem;\n        -webkit-transition: all 0.1s ease;\n        -moz-transition: all 0.1s ease;\n        transition: all 0.1s ease; }\n        @media (max-width: 480px), screen and (max-device-width: 480px) {\n          .date-picker-component {\n            width: 90%;\n            height: 90%;\n            position: fixed;\n            top: 5%;\n            left: 5%; } }\n        .date-picker-component .input-group {\n          z-index: 110; }\n        .date-picker-component .container {\n          height: 100%; }\n          @media (max-width: 480px), screen and (max-device-width: 480px) {\n            .date-picker-component .container .calendar-container {\n              height: 91%; } }\n          .date-picker-component .container header {\n            position: relative;\n            top: 0;\n            left: 0;\n            vertical-align: middle;\n            background-color: #fff; }\n            .date-picker-component .container header .days-of-week {\n              background-color: #0275d8;\n              color: #fff; }\n            .date-picker-component .container header table {\n              border-top: none !important; }\n              .date-picker-component .container header table th, .date-picker-component .container header table td {\n                text-align: center; }\n            .date-picker-component .container header button {\n              border: none;\n              border-radius: 0;\n              color: #0275d8;\n              background-color: #fff;\n              width: 15%; }\n              .date-picker-component .container header button:active {\n                background-color: #eceeef; }\n              .date-picker-component .container header button.button-disable {\n                color: #eceeef;\n                cursor: default; }\n            .date-picker-component .container header .date-range {\n              width: 70%; }\n              .date-picker-component .container header .date-range span {\n                background-color: #eceeef;\n                border-left: none;\n                border-right: none; }\n            .date-picker-component .container header .input-group-addon {\n              border: none;\n              background-color: #fff !important; }\n            .date-picker-component .container header input {\n              border: none;\n              display: inline-block;\n              margin: 1px auto 0 auto;\n              cursor: pointer;\n              background-color: #fff !important; }\n            .date-picker-component .container header input:read-only, .date-picker-component .container header .form-control[readonly] {\n              background-color: #fff !important; }\n            .date-picker-component .container header input.target {\n              color: #0275d8; }\n              .date-picker-component .container header input.target::-webkit-input-placeholder {\n                color: #0275d8; }\n              .date-picker-component .container header input.target::-moz-placeholder {\n                color: #0275d8; }\n              .date-picker-component .container header input.target:-moz-placeholder {\n                color: #0275d8; }\n              .date-picker-component .container header input.target:-ms-input-placeholder {\n                color: #0275d8; }\n    "],
        template: "\n      <div class=\"date-picker-overlay\" aria-hidden=\"true\"\n          *ngIf=\"calendarDisplayed\" \n          (click)=\"hideCalendar()\">\n      </div>\n\n      <div class=\"date-picker-content\">\n          <ng-content></ng-content>\n\n          <div class=\"date-picker-component\" *ngIf=\"calendarDisplayed\"\n              [style.left]=\"calendarX\"\n              [style.top]=\"calendarY\">\n              <div class=\"container p-a-0\">\n                  <header>\n                      <button type=\"button\" class=\"btn btn-secondary pull-left\"\n                          (click)=\"scrollPrevMonth()\" [class.button-disable]=\"disablePrev()\">\n                          <i class=\"fa fa-chevron-left\"></i>\n                      </button>\n                      <div class=\"date-range pull-left input-group\">\n                          <input type=\"text\" class=\"form-control text-xs-center\" \n                              id=\"startDate\" [(ngModel)]=\"inputDate\" readonly />\n                      </div>\n                      <button type=\"button\" class=\"btn btn-secondary pull-right\"\n                          (click)=\"scrollNextMonth()\" [class.button-disable]=\"disableNext()\">\n                          <i class=\"fa fa-chevron-right\"></i>\n                      </button>\n                      <table class=\"table m-b-0 days-of-week\">\n                          <tbody>\n                          <tr>\n                              <th>S</th>\n                              <th>M</th>\n                              <th>T</th>\n                              <th>W</th>\n                              <th>T</th>\n                              <th>F</th>\n                              <th>S</th>\n                          </tr>\n                          </tbody>\n                      </table>\n                  </header>\n                  <div class=\"calendar-container m-a-0\">\n                      <infinite-scroller\n                          (next)=\"addNextMonth()\"\n                          (prev)=\"addPrevMonth()\"\n                          distance=\"100\"\n                          [height]=\"calendarHeight\"\n                          [hideScrollbar]=\"true\">\n                          <date-picker-calendar scroll-item\n                              *ngFor=\"let month of calendarMonths; let i=index\" \n                              [id]=\"i\"\n                              [minDate]=\"minDate\" [maxDate]=\"maxDate\"\n                              [dateFilter]=\"dateFilter\"\n                              [currentMonth]=\"month\" \n                              [(selectedDate)]=\"selectedDate\">\n                              {{i}}\n                          </date-picker-calendar>\n                      </infinite-scroller>\n                  </div>\n              </div>\n          </div>\n      </div>\n    ",
        changeDetection: ChangeDetectionStrategy.OnPush
    }), 
    __metadata('design:paramtypes', [ChangeDetectorRef, Renderer])
], DatePicker);
