var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Directive, ChangeDetectionStrategy, ChangeDetectorRef, Renderer } from '@angular/core';
import { EventEmitter, ElementRef, ViewChild, ContentChildren, ContentChild, QueryList } from '@angular/core';
import { Input, Output } from "@angular/core";
import { DateRange, DateUtils, MobileDetection } from "../../utilities/utilities";
import { DatePicker } from "./DatePicker";
import { DatePickerField, DatePickerFieldStyler } from "./DatePickerField";
import { InfiniteScroller } from "../InfiniteScroller/InfiniteScroller";
export let StartDateField = class StartDateField extends DatePickerField {
    constructor(element) {
        super();
        this.element = element;
    }
};
StartDateField = __decorate([
    Directive({
        selector: "[startDateField], .start-date-field",
    }), 
    __metadata('design:paramtypes', [ElementRef])
], StartDateField);
export let EndDateField = class EndDateField extends DatePickerField {
    constructor(element) {
        super();
        this.element = element;
    }
};
EndDateField = __decorate([
    Directive({
        selector: "[endDateField], .start-date-field",
    }), 
    __metadata('design:paramtypes', [ElementRef])
], EndDateField);
export let DateRangePicker = class DateRangePicker extends DatePicker {
    constructor(changeDetector, renderer) {
        super(changeDetector, renderer);
        this.valueChange = new EventEmitter();
        this._dateTarget = false;
        this.calendarHeight = MobileDetection.isAny() || window.innerWidth <= 480 || window.outerWidth <= 480 ? "auto" : "300px";
        this.startDateChange = new EventEmitter();
        this.endDateChange = new EventEmitter();
    }
    set value(value) {
        this._selectedDate = this.handleRangeInput(value).start;
    }
    set minDate(value) {
        this._minDate = DateUtils.handleDateInput(value);
    }
    get minDate() { return this._minDate; }
    ;
    set maxDate(value) {
        this._maxDate = DateUtils.handleDateInput(value);
    }
    get maxDate() { return this._maxDate; }
    get selectedDate() { return this._selectedDate; }
    ;
    set selectedDate(value) {
        this.selectDate(value);
    }
    get inputStartDate() {
        return this.startDateField != null ? this.startDateField.value : "";
    }
    get inputEndDate() {
        return this.endDateField != null ? this.endDateField.value : "";
    }
    set startDate(value) {
        this._startDate = DateUtils.handleDateInput(value);
        if (this.startDateField != null)
            this.startDateField.value = this._startDate.toLocaleDateString();
    }
    get startDate() { return this._startDate; }
    set endDate(value) {
        this._endDate = DateUtils.handleDateInput(value);
        if (this.endDateField != null)
            this.endDateField.value = this._endDate.toLocaleDateString();
    }
    get endDate() { return this._endDate; }
    ngAfterContentInit() {
        if (typeof this.startDateField === "undefined")
            throw "Fuel-UI Error: DateRangePicker missing startDate field";
        let startDateValue = DateUtils.handleDateInput(this.startDateField.value);
        if (this.startDateField.value.length > 0
            && DateUtils.isValidDate(startDateValue))
            this.selectDate(startDateValue, false);
        else {
            this.selectDate(this._startDate, false);
            this.startDateField._value = this._startDate.toLocaleDateString();
        }
        this.startDateField.select
            .subscribe((event) => {
            this.showCalendar(event);
            this.focusStartDate();
        });
        /* removed due to binding issues in FF
        this.startDateField.dateChange
            .subscribe((date: Date) => {
                if(this.startDate !== date)
                    this.startDate = date;
            });*/
        if (typeof this.endDateField === "undefined")
            throw "Fuel-UI Error: DateRangePicker missing endDate field";
        let endDateValue = DateUtils.handleDateInput(this.endDateField.value);
        if (this.endDateField.value.length > 0
            && DateUtils.isValidDate(endDateValue))
            this.selectDate(endDateValue, true);
        else {
            this.selectDate(this._endDate, true);
            this.endDateField._value = this._endDate.toLocaleDateString();
        }
        this.endDateField.select
            .subscribe((event) => {
            this.showCalendar(event);
            this.focusEndDate();
        });
        /* removed due to binding issues in FF
        this.endDateField.dateChange
            .subscribe((date: Date) => {
                if(this.endDate !== date)
                    this.endDate = date;
            });*/
        this.dateFieldIcons.map((i) => {
            i.selectEvent.subscribe((event) => {
                this.showCalendar(event);
            });
        });
        this.generateMonths();
    }
    selectDate(value, target) {
        this._selectedDate = value;
        let dateTarget = (typeof target !== "undefined" && target != null) ? target : this._dateTarget;
        if (!dateTarget) {
            this.startDate = value;
            if (this.startDateChange != null)
                this.startDateChange.next(this._startDate);
            if (DateUtils.isValidDate(this.endDate) && this.startDate > this.endDate)
                this.endDate = new Date(this.startDate.getTime() + 24 * 60 * 60 * 1000);
        }
        else {
            this.endDate = value;
            this.hideCalendar();
            if (this.endDateChange != null)
                this.endDateChange.next(this._endDate);
            if (DateUtils.isValidDate(this.startDate) && this.endDate < this.startDate)
                this.startDate = new Date(this.endDate.getTime() - 24 * 60 * 60 * 1000);
        }
        this._dateTarget = !dateTarget;
        if (this.startDate != null && this.endDate != null) {
            let startDate = new Date(this.startDate.getFullYear(), this.startDate.getMonth(), this.startDate.getDate());
            let endDate = new Date(this.endDate.getFullYear(), this.endDate.getMonth(), this.endDate.getDate());
            this.valueChange.next(new DateRange(startDate, endDate));
        }
        this.changeDetector.markForCheck();
    }
    handleRangeInput(value) {
        if (!(value instanceof DateRange))
            throw "DateRangePicker error: input is not of type DateRange";
        var range = value;
        this.startDate = range.start;
        this.endDate = range.end;
        return range;
    }
    focusStartDate() {
        this._dateTarget = false;
    }
    focusEndDate() {
        this._dateTarget = true;
    }
    checkStartDateTarget() {
        return !this._dateTarget;
    }
    checkEndDateTarget() {
        return this._dateTarget;
    }
};
__decorate([
    Output(), 
    __metadata('design:type', Object)
], DateRangePicker.prototype, "valueChange", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DateRangePicker.prototype, "value", null);
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DateRangePicker.prototype, "minDate", null);
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DateRangePicker.prototype, "maxDate", null);
__decorate([
    Input(), 
    __metadata('design:type', Function)
], DateRangePicker.prototype, "dateFilter", void 0);
__decorate([
    ViewChild(InfiniteScroller), 
    __metadata('design:type', InfiniteScroller)
], DateRangePicker.prototype, "calendarScroller", void 0);
__decorate([
    ContentChild(StartDateField), 
    __metadata('design:type', StartDateField)
], DateRangePicker.prototype, "startDateField", void 0);
__decorate([
    ContentChild(EndDateField), 
    __metadata('design:type', EndDateField)
], DateRangePicker.prototype, "endDateField", void 0);
__decorate([
    ContentChildren(DatePickerFieldStyler), 
    __metadata('design:type', QueryList)
], DateRangePicker.prototype, "dateFieldIcons", void 0);
__decorate([
    Output(), 
    __metadata('design:type', Object)
], DateRangePicker.prototype, "startDateChange", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DateRangePicker.prototype, "startDate", null);
__decorate([
    Output(), 
    __metadata('design:type', Object)
], DateRangePicker.prototype, "endDateChange", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Object), 
    __metadata('design:paramtypes', [Object])
], DateRangePicker.prototype, "endDate", null);
DateRangePicker = __decorate([
    Component({
        selector: "date-range-picker",
        template: "\n      <div class=\"date-picker-overlay\" aria-hidden=\"true\"\n          *ngIf=\"calendarDisplayed\" \n          (click)=\"hideCalendar()\">\n      </div>\n\n      <div class=\"date-picker-content\">\n          <ng-content></ng-content>\n\n          <div class=\"date-picker-component\" *ngIf=\"calendarDisplayed\"\n              [style.left]=\"calendarX\" [style.top]=\"calendarY\">\n              <div class=\"container p-a-0\">\n                  <header>\n                      <button type=\"button\" class=\"btn btn-secondary pull-left\"\n                          (click)=\"scrollPrevMonth()\" [class.button-disable]=\"disablePrev()\">\n                          <i class=\"fa fa-chevron-left\"></i>\n                      </button>\n                      <div class=\"date-range pull-left input-group\">\n                          <input type=\"text\" class=\"form-control text-xs-center\" \n                              [class.target]=\"checkStartDateTarget()\"\n                              (click)=\"focusStartDate()\"\n                              id=\"startDate\" [(ngModel)]=\"inputStartDate\" readonly \n                              placeholder=\"{{startLabel}}\" />\n                          <span class=\"input-group-addon\"> - </span>\n                          <input type=\"text\" class=\"form-control text-xs-center\" \n                              [class.target]=\"checkEndDateTarget()\"\n                              (click)=\"focusEndDate()\"\n                              id=\"endDate\" [(ngModel)]=\"inputEndDate\" readonly \n                              placeholder=\"{{endLabel}}\" />\n                      </div>\n                      <button type=\"button\" class=\"btn btn-secondary pull-right\"\n                          (click)=\"scrollNextMonth()\" [class.button-disable]=\"disableNext()\">\n                          <i class=\"fa fa-chevron-right\"></i>\n                      </button>\n                      <table class=\"table m-b-0 days-of-week\">\n                          <tbody>\n                          <tr>\n                              <th>S</th>\n                              <th>M</th>\n                              <th>T</th>\n                              <th>W</th>\n                              <th>T</th>\n                              <th>F</th>\n                              <th>S</th>\n                          </tr>\n                          </tbody>\n                      </table>\n                  </header>\n                  <div class=\"calendar-container m-a-0\">\n                      <infinite-scroller\n                          (next)=\"addNextMonth()\"\n                          (prev)=\"addPrevMonth()\"\n                          distance=\"100\"\n                          height=\"{{calendarHeight}}\"\n                          hideScrollbar=\"true\">\n                          <date-picker-calendar scroll-item\n                              *ngFor=\"let month of calendarMonths; let i=index\" \n                              [id]=\"i\"\n                              [minDate]=\"minDate\" [maxDate]=\"maxDate\"\n                              [dateFilter]=\"dateFilter\"\n                              [currentMonth]=\"month\" \n                              [(selectedDate)]=\"selectedDate\"\n                              [(startDate)]=\"startDate\"\n                              [(endDate)]=\"endDate\"\n                              [dateTarget]=\"_dateTarget\" \n                              (selectedDate)=\"hideCalendar()\">\n                              {{i}}\n                          </date-picker-calendar>\n                      </infinite-scroller>\n                  </div>\n              </div>\n          </div>\n    \n      </div>\n    ",
        changeDetection: ChangeDetectionStrategy.OnPush
    }), 
    __metadata('design:paramtypes', [ChangeDetectorRef, Renderer])
], DateRangePicker);
