var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component } from '@angular/core';
import { Event, EventColumns, EventsDefaultSort, Attribute, AttributeColumns, AttributesDefaultSort } from '../../utilities/demoUtilities';
export let InfiniteScrollerDemo = class InfiniteScrollerDemo {
    constructor() {
        this.infiniteScrollItems = [];
        this.infiniteScrollMin = 0;
        this.infiniteScrollMax = 1;
        this.markupExample = `&lt;infinite-scroller 
    (next)=&quot;infinteScrollNext()&quot; 
    (prev)=&quot;infiniteScrollPrev()&quot; 
    height=&quot;300px&quot;
    distance=&quot;120&quot;
    hideScrollbar=&quot;true&quot;&gt;
    &lt;div *ngFor=&quot;#item of infiniteScrollItems&quot; 
        class=&quot;card p-a scroll-item&quot;&gt;
        &lt;div class=&quot;card-block&quot;&gt;
            &lt;h4 class=&quot;card-title&quot;&gt;Some Item&lt;/h4&gt;
            &lt;p class=&quot;card-text&quot;&gt;{{item}}&lt;/p&gt;
        &lt;/div&gt;
    &lt;/div&gt;
&lt;/infinite-scroller&gt;`;
        this.codeExample = `export class InfiniteScrollerDemo {
    infiniteScrollItems: string[] = [];
    infiniteScrollMin: number = 0;
    infiniteScrollMax: number = 1;

    constructor() {
        for (let i = 0; i < 10; i++) {
            this.infinteScrollNext(false);
        }
    }

    infiniteScrollPrev(): void {
        var newItem = "";
        for (let i = 0; i < 50; i++) {
            newItem += "Test " + this.infiniteScrollMin + " ";
        }

        this.infiniteScrollMin--;
        this.infiniteScrollItems.unshift(newItem);
    }

    infinteScrollNext(clean: boolean = true): void {
        var newItem = "";
        for (let i = 0; i < 50; i++) {
            newItem += "Test " + this.infiniteScrollMax + " ";
        }

        this.infiniteScrollMax++;
        this.infiniteScrollItems.push(newItem);
    }
}`;
        this.attributes = [
            new Attribute('height', 'string', 'auto', "Height of element. Examples: '300px', '10%', 'auto', etc."),
            new Attribute('distance', 'number', '100', 'How far up and down the user can scroll for more scroll items'),
            new Attribute('hideScrollbar', 'boolean', 'false', 'Hide the scrollbar of the InfiniteScroller')
        ];
        this.attributesColumns = AttributeColumns;
        this.attributesSort = AttributesDefaultSort;
        this.events = [
            new Event('next', 'null', 'When a scroll item is passed when scrolling down'),
            new Event('prev', 'null', 'When a scroll item is passed when scrolling up'),
        ];
        this.eventsColumns = EventColumns;
        this.eventsSort = EventsDefaultSort;
        for (let i = 0; i < 10; i++) {
            this.infinteScrollNext(false);
        }
    }
    infiniteScrollPrev() {
        var newItem = "";
        for (let i = 0; i < 50; i++) {
            newItem += "Test " + this.infiniteScrollMin + " ";
        }
        this.infiniteScrollMin--;
        this.infiniteScrollItems.unshift(newItem);
    }
    infinteScrollNext(clean = true) {
        var newItem = "";
        for (let i = 0; i < 50; i++) {
            newItem += "Test " + this.infiniteScrollMax + " ";
        }
        this.infiniteScrollMax++;
        this.infiniteScrollItems.push(newItem);
    }
};
InfiniteScrollerDemo = __decorate([
    Component({
        template: "\n    <div class=\"row\">\n        <div class=\"col-md-12\">\n            <div class=\"card card-block\">\n                <h2 class=\"card-title\">Infinite Scroller</h2>\n                <p class=\"card-text\">Infinite Scroller is a custom component to infinitely scroll</p>\n            </div>\n        </div>\n    </div>\n\n    <section class=\"row m-a\">\n        <div class=\"col-md-6\" style=\"border: 1px solid #333; background-color: #EEE\">\n            <infinite-scroller \n                (next)=\"infinteScrollNext()\" \n                (prev)=\"infiniteScrollPrev()\" \n                height=\"300px\"\n                distance=\"120\"\n                hideScrollbar=\"true\">\n                <div *ngFor=\"let item of infiniteScrollItems\" \n                    class=\"card p-a scroll-item\" style=\"background-color: #FFF\">\n                    <div class=\"card-block\">\n                        <h4 class=\"card-title\">Some Item</h4>\n                        <p class=\"card-text\">{{item}}</p>\n                    </div>\n                </div>\n            </infinite-scroller>\n        </div>\n    </section>\n\n    <div class=\"source\">\n    <h3>Import</h3>\n    <pre>\n    <code class=\"language-javascript\" code-highlight>\n    {{'import {INFINITE_SCROLLER_PROVIDERS} from \"fuel-ui/fuel-ui\"'}};\n    </code>\n    </pre>\n\n    <h3>Getting Started</h3>\n    <p>The Infinite Scroller component allows for asynchronous ability to show items as a user scrolls. Use the <code>next</code> and <code>prev</code> events to know when to start adding items to show or removing items for performance reasons.</p>\n\n    <h3>Usage</h3>\n    <tabset>\n    <tab heading=\"HTML\">\n    <pre>\n    <code class=\"language-markup\" code-highlight [innerHTML]=\"markupExample\">\n    </code>\n    </pre>\n    </tab>\n    <tab heading=\"TypeScript\">\n    <pre>\n    <code class=\"language-javascript\" code-highlight [innerHTML]=\"codeExample\">\n    </code>\n    </pre>\n    </tab>\n    </tabset>\n\n    <h3>Attributes</h3>\n    <table-sortable\n        [columns]=\"attributesColumns\"\n        [data]=\"attributes\"\n        [sort]=\"attributesSort\">\n        Loading table...\n    </table-sortable>\n\n    <h3>Events</h3>\n    <table-sortable\n        [columns]=\"eventsColumns\"\n        [data]=\"events\"\n        [sort]=\"eventsSort\">\n        Loading table...\n    </table-sortable>\n\n    </div>\n  "
    }), 
    __metadata('design:paramtypes', [])
], InfiniteScrollerDemo);
