var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component } from '@angular/core';
import { TableSortableColumn } from './TableSortable';
import { Attribute, AttributeColumns, AttributesDefaultSort } from '../../utilities/demoUtilities';
export let TableSortableDemo = class TableSortableDemo {
    constructor() {
        this.codeExample1 = `&lt;table-sortable
    [columns]=&quot;columns&quot;
	[data]=&quot;rows&quot;
	[sort]=&quot;sorting&quot;&gt;
  Loading table...
&lt;/table-sortable&gt;`;
        this.codeExample2 = `export class TableSortableExample {
    rows: any[] = [
    {
      Name: 'Data 1',
      Amount: 100.23,
      Date: 1441588216000,
      Desc: "You can't sort"
    },
    {
      Name: 'Data 2',
      Amount: 0.875623,
      Date: 1442387616000,
      Desc: "On this"
    },
    {
      Name: 'Data 3',
      Amount: .010123,
      Date: 1442187616000,
      Desc: "Table column"
    }
  ];
  columns: TableSortableColumn[] = [
    {
      display: 'Column 1', //The text to display
      variable: 'Name', //The name of the key that's apart of the data array
      filter: 'text', //The type data type of the column (number, text, date, etc.)
      sortable: true //Whether the user can sort on the column
    },
    new TableSortableColumn('Column 2', 'Amount', 'decimal : 1.0-2'),
    new TableSortableColumn('Column 3', 'Date', 'dateTime'),
    new TableSortableColumn('Column 4', 'Desc', 'text', false)
  ];
  sorting: TableSortableSorting = {
    column: 'Name', //to match the variable of one of the columns
    descending: false
  };
}`;
        this.rows = [
            {
                Name: 'Data 1',
                Amount: 100.23,
                Date: 1441588216000,
                Desc: "You can't sort"
            },
            {
                Name: 'Data 2',
                Amount: 0.875623,
                Date: 1442387616000,
                Desc: "On this"
            },
            {
                Name: 'Data 3',
                Amount: .010123,
                Date: 1442187616000,
                Desc: "Table column"
            }
        ];
        this.columns = [
            {
                display: 'Column 1',
                variable: 'Name',
                filter: 'text',
                sortable: true //Whether the user can sort on the column
            },
            new TableSortableColumn('Column 2', 'Amount', 'decimal : 1.0-2'),
            new TableSortableColumn('Column 3', 'Date', 'dateTime'),
            new TableSortableColumn('Column 4', 'Desc', 'text', false)
        ];
        this.sorting = {
            column: 'Name',
            descending: false
        };
        this.attributes = [
            new Attribute('columns', 'TableSortableColumn[]', 'null', 'Array of all columns to be displayed and how to format them for ordering'),
            new Attribute('data', 'any[]', 'null', 'Any arbitrary array of objects'),
            new Attribute('sort', 'TableSortableSorting', 'null', 'Which column to sort on and which direction (ascending or descending)')
        ];
        this.attributesColumns = AttributeColumns;
        this.attributesSort = AttributesDefaultSort;
    }
};
TableSortableDemo = __decorate([
    Component({
        template: "\n    <div class=\"row\">\n        <div class=\"col-md-12\">\n            <div class=\"card card-block\">\n                <h2 class=\"card-title\">TableSortable</h2>\n                <p class=\"card-text\">TableSortable is a custom element to display any arbitrary data in a sortable data table</p>\n            </div>\n        </div>\n    </div>\n\n    <section class=\"row m-a\">\n        <div class=\"col-md-8\">\n            <table-sortable\n                [columns]=\"columns\"\n                [data]=\"rows\"\n                [sort]=\"sorting\">\n                Loading table...\n            </table-sortable>\n        </div>\n    </section>\n\n    <div class=\"source\">\n    <h3>Import</h3>\n    <pre>\n    <code class=\"language-javascript\" code-highlight>\n    {{'import {TableSortable, TableSortableColumn, TableSortableSorting} from \"fuel-ui/fuel-ui\"'}}\n    </code>\n    </pre>\n\n    <h3>Getting Started</h3>\n    <p>TableSortable is a custom element to display any arbitrary data in a sortable table</p>\n\n    <h3>Usage</h3>\n    <tabset>\n    <tab heading=\"HTML\">\n    <pre>\n    <code class=\"language-markup\" code-highlight [innerHTML]=\"codeExample1\">\n\n    </code>\n    </pre>\n    </tab>\n    <tab heading=\"TypeScript\">\n    <pre>\n    <code class=\"language-javascript\" code-highlight [innerHTML]=\"codeExample2\">\n    </code>\n    </pre>\n    </tab>\n    </tabset>\n\n    <h3>Attributes</h3>\n    <table-sortable\n        [columns]=\"attributesColumns\"\n        [data]=\"attributes\"\n        [sort]=\"attributesSort\">\n        Loading table...\n    </table-sortable>\n\n    </div>\n  "
    }), 
    __metadata('design:paramtypes', [])
], TableSortableDemo);
